package com.hfkj.service.item.impl;

import com.hfkj.dao.EnItemMapper;
import com.hfkj.entity.EnItem;
import com.hfkj.entity.EnItemExample;
import com.hfkj.service.item.EnItemService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("enItemService")
public class EnItemServiceImpl implements EnItemService {

    @Resource
    private EnItemMapper enItemMapper;

    @Override
    public void create(EnItem enItem) {
        enItemMapper.insert(enItem);
    }

    @Override
    public void update(EnItem enItem) {
        enItemMapper.updateByPrimaryKey(enItem);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        if (fullDelete) {
            enItemMapper.deleteByPrimaryKey(id);
        } else {
            EnItem enItem = queryDetail(id);
            enItem.setStatus(0);
            enItem.setUpdateTime(new Date());
            update(enItem);
        }
    }

    @Override
    public EnItem queryDetail(Long id) {
        return enItemMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnItem queryDetailByMap(Map<String, Object> map) {
        EnItemExample example = new EnItemExample();
        EnItemExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectAddress"))) {
            criteria.andProjectAddressLike("%"+MapUtils.getString(map, "projectAddress")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectLeader"))) {
            criteria.andProjectLeaderLike("%"+MapUtils.getString(map, "projectLeader")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectName"))) {
            criteria.andProjectNameLike("%"+MapUtils.getString(map, "projectName")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {

            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        example.setOrderByClause("create_time desc");

        List<EnItem> enItems = enItemMapper.selectByExample(example);

        return enItems.isEmpty() ? null : enItems.get(0);

    }

    @Override
    public List<EnItem> getList(Map<String, Object> map) {
        EnItemExample example = new EnItemExample();
        EnItemExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectAddress"))) {
            criteria.andProjectAddressLike("%"+MapUtils.getString(map, "projectAddress")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectLeader"))) {
            criteria.andProjectLeaderLike("%"+MapUtils.getString(map, "projectLeader")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "projectName"))) {
            criteria.andProjectNameLike("%"+MapUtils.getString(map, "projectName")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {

            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }



        example.setOrderByClause("create_time desc");

        return enItemMapper.selectByExample(example);
    }
}
